@@ -88,23 +88,8 @@ class DocTree(object):
 
     def publish_doc_tree(self, ctx, build_dir, dest_url):
         print("Publish to ", dest_url)
+        cmd = ctx.rsync_command.format(dest_url=dest_url)
         with cd(build_dir):
-            args = ['rsync', '-e', 'ssh', '-r']
-            args += ['--verbose']
-            args += ['--progress']  # show progress
-            args += ['--delete']  # delete files in dest
-            args += ['--times']  # preserve timestamps
-
-            # the problem with --times is that it fails when several
-            # users can publish to the same server alternatively.
-            # Only the owner of a file can change the mtime, other
-            # users can't, even if they have write permission through
-            # the group.
-
-            args += ['--exclude', '.doctrees']
-            args += ['./']  # source
-            args += [dest_url]  # dest
-            cmd = ' '.join(args)
             # must_confirm("%s> %s" % (build_dir, cmd))
             ctx.run(cmd, pty=True)
 
