@@ -39,6 +39,9 @@ import os
 import calendar
 import datetime
 
+from sphinx.directives.other import Author
+
+
 import jinja2
 
 from babel.dates import format_date
@@ -82,8 +85,8 @@ JINJA_ENV = jinja2.Environment(
 
 
 class BloggerDay(object):
-    def __init__(self, docname, *args, **kwargs):
-        self.docnames = [docname]
+    def __init__(self, *args, **kwargs):
+        self.docnames = []
         self.date = datetime.date(*args, **kwargs)
 
 
@@ -110,39 +113,51 @@ class BloggerYear(object):
         #~ print "20130113 Year.__init__", blogname, self.year
         #~ self.blogname = blogname
         self.days = []
-        self.dates = set()
+        self.dates = {}
         #~ self.years = set()
         #~ self.starting_year = int(starting_year)
         top = os.path.dirname(env.doc2path(env.docname))
         #~ print top
+        # print("20211021", year, top, getattr(env, 'blog_instances', None))
         for (dirpath, dirnames, filenames) in os.walk(top):
             del dirnames[:]  # don't descend another level
             #~ unused, year = dirpath.rsplit(os.path.sep,2)
             #~ year = int(year)
             #~ assert year in self.years
-            d = None
+            currentday = None
             docnames = sorted([fn[:-4] for fn in filenames if fn.endswith('.rst')])
             for docname in sorted(docnames):
                 if docname == "index":
                     continue
-                if len(docname) == 4:
-                    d = self.docname_to_day(docname)
-                    self.days.append(d)
-                    self.dates.add(d.date)
-                    #~ self.years.add(s)
-                elif d is not None:
-                    d.docnames.append(docname)
+                d = self.docname_to_day(docname, currentday)
+                if d is not None:
+                    dates_item = self.dates.get(d.date, None)
+                    if dates_item is None:
+                        self.dates[d.date] = d
+                    # self.dates.add(d.date)
+                    currentday = d
 
         #~ self.years = sorted(self.years)
         if not hasattr(env, 'blog_instances'):
             env.blog_instances = dict()
         years = env.blog_instances.setdefault(blogname, dict())
         years[self.year] = self
+        # print("20211021b", year, top, env.blog_instances)
 
-    def docname_to_day(self, s):
-        month = int(s[:2])
-        day = int(s[2:4])
-        return BloggerDay(s, self.year, month, day)
+    def docname_to_day(self, s, currentday):
+        if len(s) < 4:
+            return None
+        try:
+            month = int(s[:2])
+            day = int(s[2:4])
+        except ValueError:
+            return None
+        if currentday is None or currentday.date.month != month \
+            or currentday.date.day != day:
+                currentday = BloggerDay(self.year, month, day)
+                self.days.append(currentday)
+        currentday.docnames.append(s)
+        return currentday
 
 
 def year2docname(y):
@@ -153,8 +168,8 @@ def year2docname(y):
 def navigator(years, current):
     """`years` is an iterable of :class:`BloggerYear` instances.
     """
-    if len(years) < 2:
-        return ""
+    # if len(years) < 2:
+    #     return ""
     chunks = []
     for y in years:
         if y == current:
@@ -191,6 +206,7 @@ def get_blogger_years(env, blogname):
         return []
     years = list(blog.values())
     years.sort(key=lambda f: f.year)
+    # print(20220109, [y.year for y in years])
     return years
 
 
@@ -203,13 +219,13 @@ class MainBlogIndexDirective(InsertInputDirective):
     raw_insert = True
 
     def get_rst(self):
-        #~ print 'MainBlogIndexDirective.get_rst()'
         env = self.state.document.settings.env
         blogname, index = env.docname.rsplit('/', 2)
         if index != 'index':
             raise Exception("Allowed only inside index.rst file")
         text = ''
         years = get_blogger_years(env, blogname)
+        # print('20211021 MainBlogIndexDirective.get_rst()', years)
         text += navigator(years, None)
         text += '\n'.join(self.content)
         if len(years) == 0:
@@ -217,6 +233,7 @@ class MainBlogIndexDirective(InsertInputDirective):
         else:
             children = list(map(year2docname, years))
             text += toctree(*children, hidden=True)
+        # print('20211021b get_rst()', text)
         return text
 
 class YearBlogIndexDirective(InsertInputDirective):
@@ -258,9 +275,11 @@ class YearBlogIndexDirective(InsertInputDirective):
                     weeknum = iso_week
                 if day.month == month:
                     label = "%02d" % day.day
-                    docname = "%02d%02d" % (day.month, day.day)
+                    # docname = "%02d%02d" % (day.month, day.day)
                     # if blogger_year.year == iso_year and day in blogger_year.days:
-                    if day in blogger_year.dates:
+                    blogday = blogger_year.dates.get(day, None)
+                    if blogday is not None:
+                        docname = blogday.docnames[0]
                         text += " :doc:`%s <%s>` " % (label, docname)
                         num_entries += 1
                     elif day > today:
@@ -280,13 +299,15 @@ class YearBlogIndexDirective(InsertInputDirective):
 |M10| |M11| |M12|
 ===== ===== =====
 
-.. rubric:: {0}
+.. rubric:: {0}""".format("All entries:")
 
-""".format("All entries:")
-        else:
-            text += "\n\n"
+        text += "\n\n"
 
-        for day in reversed(blogger_year.days):
+        days = blogger_year.days
+        if False:
+            days = reversed(days)
+
+        for day in days:
             date_text = format_date(day.date, format="long", locale=self.language).strip()
             text += ("\n\n**{}** --- ".format(date_text))
             text += ", ".join([":doc:`{}`".format(docname) for docname in day.docnames])
@@ -350,3 +371,4 @@ def setup(app):
     app.add_directive('blogger_year', YearBlogIndexDirective)
     app.add_directive('blogger_index', MainBlogIndexDirective)
     app.add_directive('blogger_latest', LatestEntriesDirective)
+    app.add_directive('blogauthor', Author)
