@@ -52,17 +52,23 @@ def configure(globals_dict, prjspec=None, **nicknames):
 
     else:
         prjlist = []
+        # 20210716 feature removed because it causes unreproduceable situation
+        # raise Exception("20210716")
         # for p in load_projects():
-        for p in reversed(list(load_projects())):
-            if str(this_conf_file).startswith(str(p.root_dir)):
-                # print("20190122 {} startswith  {}".format(this_conf_file, p.root_dir))
-                continue
-            prjlist.append(p)
+        # for p in reversed(list(load_projects())):
+        #     if not str(this_conf_file).startswith(str(p.root_dir)):
+        #         # print("20190122 {} startswith  {}".format(this_conf_file, p.root_dir))
+        #         prjlist.append(p)
 
     for k, v in nicknames.items():
         p = get_project_from_nickname(k)
         if p:
-            prjlist.append(p)
+            # makedocs in demo projects in the book failed to load book
+            # if not str(this_conf_file).startswith(str(p.root_dir)):
+            if this_conf_file.parent != p.root_dir:
+                prjlist.append(p)
+            # else:
+            #     print("20210708 skipping {} because {}".format(p, this_conf_file))
         else:
             intersphinx_mapping[k] = v
 
@@ -72,7 +78,7 @@ def configure(globals_dict, prjspec=None, **nicknames):
         # projects. Possible side effects.
         # print("20180428 {} {}".format(prj.name, prj.config['doc_trees']))
         # config = prj.inv_namespace.configuration()
-        # print("20180428 {} {}".format(prj.name, config['doc_trees']))
+        # print("20210716 {}".format(prj))
         # ctx = Context(config)
         # for doc_tree in prj.config['doc_trees']:
         count = 0
@@ -105,7 +111,8 @@ def configure(globals_dict, prjspec=None, **nicknames):
                     # p = prj.root_dir / (doc_tree + '/.build/objects.inv')
                     p = src_path / '.build/objects.inv'
                     if p.exists():
-                        logger.info("Found local {}".format(p))
+                        pass
+                        # logger.info("Found local {}".format(p))
                     else:
                         logger.info("File %s does not exist", p)
                         p = None
@@ -118,9 +125,11 @@ def configure(globals_dict, prjspec=None, **nicknames):
             k = str(k)
 
             if k in intersphinx_mapping:
-                raise Exception("Duplicate intersphinx key {} used for {} "
-                                "(you ask to redefine it to {})".format(
-                    k, intersphinx_mapping[k], p))
+                logger.info("Modify intersphinx key %s from %s to %s",
+                    k, intersphinx_mapping[k], p)
+            #     raise Exception("Duplicate intersphinx key {} used for {} "
+            #                     "(you ask to redefine it to {})".format(
+            #         k, intersphinx_mapping[k], p))
             if p is not None:
                 p = str(p)
             intersphinx_mapping[k] = (url, p)
